@@ -39,11 +39,11 @@ public:
     explicit KWalletConfig(QWidget *parent = nullptr, const QVariantList & = QVariantList());
     virtual ~KWalletConfig();
 
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 
-    QString quickHelp() const Q_DECL_OVERRIDE;
+    QString quickHelp() const override;
 
 public slots:
     void configChanged();
